"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  The OpenAPI Specification in YAML format is available on [www](https://www.agilicus.com/www/api/agilicus-openapi.yaml) for importing to other tools.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2026.01.23
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import agilicus_api
from agilicus_api.model.agent_connector_authz_stats import AgentConnectorAuthzStats
from agilicus_api.model.agent_connector_proxy_stats import AgentConnectorProxyStats
from agilicus_api.model.agent_connector_share_stats import AgentConnectorShareStats
from agilicus_api.model.agent_connector_specific_stats import AgentConnectorSpecificStats
from agilicus_api.model.agent_connector_system_stats import AgentConnectorSystemStats
from agilicus_api.model.agent_connector_transport_stats import AgentConnectorTransportStats
from agilicus_api.model.agent_connector_user_stats import AgentConnectorUserStats
from agilicus_api.model.application_service_stats_group import ApplicationServiceStatsGroup
from agilicus_api.model.application_stats_list import ApplicationStatsList
from agilicus_api.model.connector_diagnostic_stats import ConnectorDiagnosticStats
from agilicus_api.model.connector_stats import ConnectorStats
from agilicus_api.model.connector_stats_metadata import ConnectorStatsMetadata
from agilicus_api.model.file_share_service_stats_group import FileShareServiceStatsGroup
from agilicus_api.model.service_forwarder_stats_group import ServiceForwarderStatsGroup
globals()['AgentConnectorAuthzStats'] = AgentConnectorAuthzStats
globals()['AgentConnectorProxyStats'] = AgentConnectorProxyStats
globals()['AgentConnectorShareStats'] = AgentConnectorShareStats
globals()['AgentConnectorSpecificStats'] = AgentConnectorSpecificStats
globals()['AgentConnectorSystemStats'] = AgentConnectorSystemStats
globals()['AgentConnectorTransportStats'] = AgentConnectorTransportStats
globals()['AgentConnectorUserStats'] = AgentConnectorUserStats
globals()['ApplicationServiceStatsGroup'] = ApplicationServiceStatsGroup
globals()['ApplicationStatsList'] = ApplicationStatsList
globals()['ConnectorDiagnosticStats'] = ConnectorDiagnosticStats
globals()['ConnectorStats'] = ConnectorStats
globals()['ConnectorStatsMetadata'] = ConnectorStatsMetadata
globals()['FileShareServiceStatsGroup'] = FileShareServiceStatsGroup
globals()['ServiceForwarderStatsGroup'] = ServiceForwarderStatsGroup
from agilicus_api.model.agent_connector_stats import AgentConnectorStats


class TestAgentConnectorStats(unittest.TestCase):
    """AgentConnectorStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAgentConnectorStats(self):
        """Test AgentConnectorStats"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AgentConnectorStats()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
